/* 	$Id: rpmVerify.h,v 1.5.8.1 2003/03/13 00:05:21 rnolden Exp $	 */

#ifndef H_VERIFY
#define H_VERIFY

#include "../config.h"
#include <qptrlist.h>
#include <qstringlist.h>

#include <rpm/rpmlib.h>

#ifndef VERIFY_FILES
#define VERIFY_FILES		(1 << 0)
#endif
#ifndef VERIFY_DEPS
#define VERIFY_DEPS		(1 << 1)
#endif
#ifndef VERIFY_SCRIPT
#define VERIFY_SCRIPT		(1 << 2)
#endif
#ifndef VERIFY_MD5
#define VERIFY_MD5		(1 << 3)
#endif

enum verifysources { VERIFY_PATH, VERIFY_PACKAGE, VERIFY_EVERY, VERIFY_RPM, 
			VERIFY_GRP };

int doVerify(const char * prefix, enum verifysources source, const QStringList &argv,
	      int verifyFlags, QStringList &result);

#endif
